@@ -13,17 +13,12 @@
 #' @param n999 {Number of bootstrap replications (default=9)}
 #' @importFrom meboot meboot
 #' @importFrom stats complete.cases
-#' @return  out {When \code{mtx} has p columns, the first output called \code{out}
+#' @return  out {When \code{mtx} has p columns, \code{out}
 #' of \code{bootPairs(mtx)} is a matrix of n999 rows and p-1 columns
 #' each containing resampled `sum' values summarizing the weighted sums 
 #' associated with all three  criteria from the function \code{silentPairs(mtx)}
 #' applied to each bootstrap sample separately.} 
 #' 
-#' {probSign} {The second output 
-#' called \code{probSign} is  a p-1 vector
-#' of probabilities of correct signs assuming that the mean of n999 values
-#' has the correct sign and assuming that sum index values inside the
-#' range [-0.05, 0.05] are neither positive nor negative but ambiguous}  
 #' @note This computation is computer intensive and generally very slow. 
 #'   It may be better to use
 #'   it at a later stage in the investigation when a preliminary 
@@ -47,23 +42,20 @@
 #' @references Vinod, H. D. Causal Paths and Exogeneity Tests 
 #' in {Generalcorr} Package for Air Pollution and Monetary Policy 
 #' (June 6, 2017). Available at SSRN: \url{https://ssrn.com/abstract=2982128}
-#' @keywords kernel regression, asymmetric correlations
 #' @examples
 #' \dontrun{
 #' options(np.messages = FALSE)
 #' set.seed(34);x=sample(1:10);y=sample(2:11)
 #' bb=bootPairs(cbind(x,y),n999=29)
-#' apply(bb$out,2,summary) #gives summary stats for n999 bootstrap sum computations
-#' bb$probSign #reports success proportion out of n999
-#' 
+#' apply(bb,2,summary) #gives summary stats for n999 bootstrap sum computations
 #' 
 #' bb=bootPairs(airquality,n999=999);options(np.messages=FALSE)
-#' apply(bb$out,2,summary) #gives summary stats for n999 bootstrap sum computations
-#' bb$probSign #reports success proportion out of n999 replicates
+#' apply(bb,2,summary) #gives summary stats for n999 bootstrap sum computations
 #' 
 #' data('EuroCrime')
 #' attach(EuroCrime)
-#' bootPairs(cbind(crim,off),n999=29) #col.1= crim causes off hence positive signs
+#' bootPairs(cbind(crim,off),n999=29)#First col. crim causes officer deployment,
+#' #hence positives signs are most sensible for such call to bootPairs
 #' #note that n999=29 is too small for real problems, chosen for quickness here.
 #' }
 #' @export
@@ -79,15 +71,8 @@ bootPairs = function(mtx, ctrl = 0, n999 = 9) {
   }
   for (k in 1:n999) {
     out[k, ] = silentPairs(mtx = Memtx[, k, 1:p], ctrl = ctrl)
-    if (k%%50 ==1) print(c("k=",k))
+    if (k%%50 ==1) print(c("k=",k)) #track the progress 
   }
   colnames(out) =colnames(mtx)[2:p]
-  signNull=sign(apply(out,2,mean))
-  probSign=rep(NA,p-1)
-  for (j in 1:(p-1)) {
-    zj=out[,j]
-    if (signNull[j]==1) probSign[j]= length(zj[zj > 0.05]) /n999
-    if (signNull[j]==-1) probSign[j]= length(zj[zj < -0.05]) /n999
-  }  
-  list(out=out, probSign=probSign)
+  return(out)
 }
